@@ -634,6 +634,46 @@ get_selected_row (const char *w, int col)
 	
 	return retval;
 }
+void
+select_component_row (char *component_name)
+{
+	GtkTreeView *view;
+	GtkTreeSelection *selection;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+
+	view = GTK_TREE_VIEW (GET_WIDGET ("component-list"));
+	selection = gtk_tree_view_get_selection (view);
+	model = gtk_tree_view_get_model (view);
+
+	if (gtk_tree_model_get_iter_first (model, &iter)) {
+		do {
+			gchar *tmp = NULL;
+
+			gtk_tree_model_get (model, &iter,
+					    COMPONENT_NAME, &tmp,
+					    -1);
+
+			if (! strcmp (component_name, tmp)) {
+				GtkTreePath *path;
+
+				path = gtk_tree_model_get_path (model, &iter);
+				gtk_tree_view_set_cursor (view, path,
+							  NULL, FALSE);
+				gtk_tree_path_free (path);
+
+				d(g_print("Autoselected %s\n", tmp));
+				g_free (tmp);
+				break;
+			}
+
+			g_free (tmp);
+		} while (gtk_tree_model_iter_next (model, &iter));
+	}
+	
+        gtk_tree_view_columns_autosize (view);
+}
+	
 
 void
 on_druid_next_clicked (GtkWidget *w, gpointer data)
@@ -761,7 +801,7 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 								    GTK_BUTTONS_OK,
 								    _("This application has not included information about "
 								      "how to submit bugs.\n\n"
-								      "If you know an email address where bugs should be sent, "
+								      "If you know an email address where bug reports should be sent, "
 								      "you will be able to specify that later.\n\n"
 								      "You may be able to find one in an \"About\" box in the "
 								      "application, or in the application's documentation."));
@@ -785,6 +825,10 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 			bugzilla_product_add_components_to_clist (druid_data.product);
 			buddy_set_text ("email-to-entry", druid_data.product->bts->email);
 		}
+		
+		if (application->component) {
+			select_component_row (application->component);
+		}
 		break;
 	}
 	case STATE_COMPONENT:
